//+------------------------------------------------------------------+
//|                                                      5-15-65.mq5 |
//|                                    Copyright 2010, Bruck Trading |
//|                                     http://www.bruck-trading.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2010, Bruck Trading"
#property link      "http://www.bruck-trading.com"
#property version   "1.00"

#include <Trade\PositionInfo.mqh>
#include <Trade\Trade.mqh>

//------------------------ Global Variables -------------------------+

datetime       TimeLastTrade; // Time last position opened

//--- Buy Conditions ---
bool BC1;
bool BC2;
bool BC3;
bool BC4;

//--- Sell Conditions ---
bool SC1;
bool SC2;
bool SC3;
bool SC4;


//------------------------ Pointers ---------------------------------+

CPositionInfo posinf;
CTrade trade;

//------------------------ Indicators -------------------------------+

// declare MA handles
int            SignalEMA;
int            FastEMA;
int            SlowEMA;

// declare MA arrays
double         SigEMA[];
double         FEMA[];
double         SEMA[];
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
//---
   // initiate moving averages
   SignalEMA           =iMA(Symbol(),PERIOD_CURRENT,5,0,MODE_EMA,PRICE_CLOSE);
   FastEMA             =iMA(Symbol(),PERIOD_CURRENT,15,0,MODE_EMA,PRICE_CLOSE);
   SlowEMA             =iMA(Symbol(),PERIOD_CURRENT,65,0,MODE_EMA,PRICE_CLOSE);
   
   //--- Buy Conditions ---
   bool BC1 = false;
   bool BC2 = false;
   bool BC3 = false;
   bool BC4 = false;

   //--- Sell Conditions ---
   bool SC1 = false;
   bool SC2 = false;
   bool SC3 = false;
   bool SC4 = false;
//---
   return(0);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---
   
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//---
   RefreshMAs();
   CheckConditions();
   CheckSignals();
  }
//+------------------------------------------------------------------+

void RefreshMAs()
  {
// Refresh SignalEMA
   CopyBuffer(SignalEMA,0,0,4,SigEMA);
   ArraySetAsSeries(SigEMA,true);

// Refresh FastEMA
   CopyBuffer(FastEMA,0,0,4,FEMA);
   ArraySetAsSeries(FEMA,true);

// Refresh SlowEMA
   CopyBuffer(SlowEMA,0,0,4,SEMA);
   ArraySetAsSeries(SEMA,true);

  }
  
void CheckConditions()
 {
   // Check Buy Conditions
   if(CheckCross(1,1))                                {BC1=true; Print("BC1 complied");}
   if(CheckCross(1,2))                                {BC2=true; Print("BC2 complied");}
   if(((FEMA[1]-SEMA[1])*10000)>=30)                  {BC3=true; Print("BC3 complied");}
   if(SymbolInfoDouble(_Symbol,SYMBOL_ASK)==SEMA[1])  {BC4=true; Print("BC4 complied");}
   
   // Check Sell Conditions
   if(CheckCross(2,1))                                {SC1=true; Print("SC1 complied");}
   if(CheckCross(2,2))                                {SC2=true; Print("SC2 complied");}
   if(((SEMA[1]-FEMA[1])*10000)>=30)                  {SC3=true; Print("SC3 complied");}
   if(SymbolInfoDouble(_Symbol,SYMBOL_ASK)==SEMA[1])  {SC4=true; Print("SC4 complied");}
 }
 
void CheckSignals()
 {
   if(1==1)
   {
      if(BC1 && BC2 && BC4)
      {
         trade.PositionOpen(_Symbol,ORDER_TYPE_BUY,0.5,SymbolInfoDouble(_Symbol,SYMBOL_ASK),SymbolInfoDouble(_Symbol,SYMBOL_BID)-500*_Point,SymbolInfoDouble(_Symbol,SYMBOL_BID)+500*_Point,NULL);
         //BC1 = BC2 = BC3 = BC4 = false;
      }
      
      if(SC1 && SC2 && SC4)
      {
         trade.PositionOpen(_Symbol,ORDER_TYPE_SELL,0.5,SymbolInfoDouble(_Symbol,SYMBOL_BID),SymbolInfoDouble(_Symbol,SYMBOL_ASK)+500*_Point,SymbolInfoDouble(_Symbol,SYMBOL_ASK)-500*_Point,NULL);
         //SC1 = SC2 = SC3 = SC4 = false;
      }
   }
 }
 
bool CheckCross(int direction, int ema)
{
   bool C1,C2;
   switch(direction)
   {
      case 1: // BUY
         switch(ema)
         {
            case 1: // Signal
               C1 = SigEMA[1]>FEMA[1];
               C2 = SigEMA[3]<FEMA[3];
               if(C1 && C2){return true;}
               break;
            
            case 2: // Fast
               C1 = FEMA[1]>SEMA[1];
               C2 = FEMA[3]<SEMA[3];
               if(C1 && C2){return true;}
               break;
               
            default:
               Print("Error occured! Wrong EMA!");
               return false;
               break;
         }
         
         break;
      
      case 2: // SELL
         switch(ema)
         {
            case 1: // Signal
               C1 = SigEMA[1]<FEMA[1];
               C2 = SigEMA[2]>FEMA[2];
               if(C1 && C2){return true;}
               break;
            
            case 2:  // Fast
               C1 = FEMA[1]<SEMA[1];
               C2 = FEMA[2]>SEMA[2];
               if(C1 && C2){return true;}
               break;
               
            default:
               Print("Error occured! Wrong EMA!");
               return false;
               break;
         }
         
         break;
      default:
         Print("Error occured! Wrong Direction!");
         return false;
         break;
   
   }
   return false;
}